@@ -1,7 +1,5 @@
 var NAVTREEINDEX5 =
 {
-"sig__tone_8h.html#ab12aa24e712072115e401539724fe900":[147,0,1,1,48,6],
-"sig__tone_8h_source.html":[147,0,1,1,48],
 "sig__tone__tests_8c.html":[147,0,3,27],
 "sig_tone_page.html":[46],
 "sig_tone_page.html#sig_tone_sec_1":[46,0],
@@ -249,5 +247,7 @@ var NAVTREEINDEX5 =
 "structg1050__core__model__t.html#a5aa9bebf108cd38726bff2dac3d6cc36":[146,0,56,1],
 "structg1050__core__model__t.html#a65c866a1b2eb6110490c39c96654176a":[146,0,56,9],
 "structg1050__core__model__t.html#a80a18dc6b30332e02b407a5f0e06d82e":[146,0,56,2],
-"structg1050__core__model__t.html#a8d7b3e367660a0d7487f1e27326127b2":[146,0,56,4]
+"structg1050__core__model__t.html#a8d7b3e367660a0d7487f1e27326127b2":[146,0,56,4],
+"structg1050__core__model__t.html#adb20c70948700007800c064893888703":[146,0,56,5],
+"structg1050__core__model__t.html#afe6f0c4e0f20981038a5df9647043ebf":[146,0,56,7]
 };
